#!/bin/bash
set -e

export PROJECT="civicrm"
export DOCKER_REGISTRY="registry.bij1.org"
export DOCKER_BUILDKIT=1

if [ -n "$CI_COMMIT_SHA" ]; then
	if [ -n "$CI_COMMIT_TAG" ]; then
		export VERSION="${CI_COMMIT_TAG}"
	else
		export VERSION="${CI_COMMIT_SHA}"
	fi
	export BRANCH_CACHE_TAG=$CI_COMMIT_BRANCH
else
	export VERSION=$(git rev-parse --short HEAD)
	export BRANCH_CACHE_TAG=$(git rev-parse --abbrev-ref HEAD | tr '/.-' '___')
fi


export DOCKER_IMAGE=${PROJECT}:$VERSION
export CACHE_FROM=${PROJECT}:$BRANCH_CACHE_TAG
export TAG_VERSION="$DOCKER_REGISTRY/$DOCKER_IMAGE"
export TAG_LATEST="$DOCKER_REGISTRY/${PROJECT}:latest"

build() {
	docker build --file ./Dockerfile --tag ${DOCKER_IMAGE} .
	docker tag $DOCKER_IMAGE $TAG_VERSION
	docker tag $DOCKER_IMAGE $TAG_LATEST
	docker tag $DOCKER_IMAGE $PROJECT:latest
}

push() {
	docker login -p ${REGISTRY_PASSWORD} -u docker $DOCKER_REGISTRY
	docker push $TAG_VERSION
	docker push $TAG_LATEST
}


case $1 in
	build)
		build
		;;
	push)
		push
		;;
esac
